@@ -220,7 +220,7 @@ repo_info = \
 {
     "K3SController":{
         "add_node_label":{
-            "args":["node_infos", "key", "value"],
+            "args":["node_infos", ["key", False], ["value", False]],
             "ret":["command_result", True, None, None, True, True]
         },
         "check_connection":{
@@ -231,54 +231,54 @@ repo_info = \
             "args":["cluster_name", "config_map_user_settings"]
         },
         "create_namespace":{
-            "args":["cluster_name", "namespace_name"]
+            "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]]
         },
         "create_node":{
             "args":["condition", "node_user_setting"],
             "ret":["node_info", True, None, None, False, True]
         },
         "create_resource_from_oss":{
-            "args":["cluster_name", "target_paths"]
+            "args":[["cluster_name", False, "Name"], ["target_paths", False, "Path", None, True]]
         },
         "create_secrets":{
-            "args":["cluster_name", "secret_user_settings"]
+            "args":[["cluster_name", False, "Name"], "secret_user_settings"]
         },
         "delete_nodes":{
             "args":["node_infos"]
         },
         "delete_resource_from_oss":{
-            "args":["cluster_name", "target_paths"]
+            "args":[["cluster_name", False, "Name"], ["target_paths", False, "Path", None, True]]
         },
         "get_config_maps":{
-            "args":["cluster_name", "namespace_name"],
+            "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]],
             "ret":["config_map", True, None, None, True, True]
         },
         "get_deployments":{
-            "args":["cluster_name", "namespace_name"],
+            "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]],
             "ret":["deployment", True, None, None, True, True]
         },
         "get_existing_nodes":{
-            "args":["cluster_name"],
+            "args":[["cluster_name", False, "Name"]],
             "ret":["node_info", True, None, None, True, True]
         },
         "get_existing_nodes_by_name":{
-            "args":["node_name"],
+            "args":[["node_name", False, "Name"]],
             "ret":["node_info", True, None, None, True, True]
         },
         "get_namespaces":{
-            "args":["cluster_name"],
+            "args":[["cluster_name", False, "Name"]],
             "ret":["namespace", True, None, None, True, True]
         },
         "get_node_metas":{
-            "args":["cluster_name"],
+            "args":[["cluster_name", False, "Name"]],
             "ret":["node_meta", True, None, None, True, True]
         },
         "get_pods":{
-            "args":["cluster_name", "namespace_name"],
+            "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]],
             "ret":["pod", True, None, None, True, True]
         },
         "get_secrets":{
-            "args":["cluster_name", "namespace_name"],
+            "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]],
             "ret":["secret", True, None, None, True, True]
         },
         "upload_to_oss_from_pod":{
